package com.ekingwin.bas.cloud.dataDictionary.web;

import com.ekingwin.bas.cloud.dataDictionary.dao.entity.DataDictionaryOption;
import com.ekingwin.bas.cloud.dataDictionary.dto.*;
import com.ekingwin.bas.cloud.dataDictionary.service.IDataDictionaryOptionService;
import com.ekingwin.bas.cloud.dataDictionary.service.IDataDictionaryService;
import com.ekingwin.bas.cloud.infra.dto.BaseResult;
import com.ekingwin.bas.cloud.infra.dto.QueryDTO;
import com.ekingwin.bas.cloud.infra.utils.db.PageCriteria;
import com.ekingwin.bas.cloud.infra.utils.web.WebUtils;
import com.ekingwin.bas.cloud.util.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;

@RestController
@RequestMapping("/data/dictionary")
@Api("数据字典")
public class DataDictionaryController {
	@Autowired
	@Qualifier(value = "dataDictionaryServiceImpl")
	private IDataDictionaryService dataDictionaryService;
	
	@Autowired
	@Qualifier(value = "dataDictionaryOptionServiceImpl")
	private IDataDictionaryOptionService dataDictionaryOptionService;

	
	@RequestMapping(value = "/query", method = RequestMethod.POST)
	@ApiOperation("查询数据字典列表")
	public PageCriteria<DataDictionaryDto> query(@RequestBody(required = false) QueryDTO query) throws Exception {
		return dataDictionaryService.query(query);
	}
	@RequestMapping(value = "/save", method = RequestMethod.POST)
	@ApiOperation("保存数据字典")
	public  BaseResult<DataDictionaryDto>   save(@RequestBody DataDictionaryDto dataDictionaryDto) throws Exception {
		BaseResult<DataDictionaryDto> baseResult = new BaseResult<DataDictionaryDto>();
		baseResult.setTimestamp(String.valueOf(new Date().getTime()));
		baseResult.setPath(WebUtils.getRequest().getRequestURI());
		try {
			dataDictionaryService.save(dataDictionaryDto);
			baseResult.setStatus("200");
			baseResult.setData(dataDictionaryDto);
		} catch (Exception e) {
			baseResult.setStatus("500");
			baseResult.setMessage(e.getMessage());
		}
		return baseResult;
	}
	
	@RequestMapping(value = "/get/{id}", method = RequestMethod.POST)
	@ApiOperation("获取数据字典信息")
	public DataDictionaryDto get(@PathVariable(value = "id")String Id) throws Exception {
		return dataDictionaryService.get(Id);
	}
	@RequestMapping(value = "/delete/{Id}", method = RequestMethod.POST)
	@ApiOperation("删除数据字典")
	public  BaseResult<DataDictionaryDto> delete(@PathVariable(value = "Id")String Id) throws Exception {
		BaseResult<DataDictionaryDto> baseResult = new BaseResult<DataDictionaryDto>();
		baseResult.setTimestamp(String.valueOf(new Date().getTime()));
		baseResult.setPath(WebUtils.getRequest().getRequestURI());
		try {
			dataDictionaryService.delete(Id);
			baseResult.setStatus("200");
		} catch (Exception e) {
			baseResult.setStatus("500");
			baseResult.setMessage(e.getMessage());
		}
		return baseResult;
	}
	
	
	
	@RequestMapping(value = "/queryoption", method = RequestMethod.POST)
	@ApiOperation("查询数据字典选项列表")
	public PageCriteria<DataDictionaryOptionDto> queryoption(@RequestBody(required = false) QueryDTO query) throws Exception {
		return dataDictionaryOptionService.query(query);
	}
	@RequestMapping(value = "/saveoption", method = RequestMethod.POST)
	@ApiOperation("保存数据字典选项(新)")
	public  BaseResult<DataDictionaryDto>   saveoption(@RequestBody DataDictionaryDto dataDictionaryDto) throws Exception {
		BaseResult<DataDictionaryDto> baseResult = new BaseResult<DataDictionaryDto>();
		baseResult.setTimestamp(String.valueOf(new Date().getTime()));
		baseResult.setPath(WebUtils.getRequest().getRequestURI());
		try {
			dataDictionaryOptionService.saveOptions(dataDictionaryDto);
			baseResult.setStatus("200");
			baseResult.setData(dataDictionaryDto);
		} catch (Exception e) {
			baseResult.setStatus("500");
			baseResult.setMessage(e.getMessage());
		}
		return baseResult;
	}
	
	@RequestMapping(value = "/addoption", method = RequestMethod.POST)
	@ApiOperation("保存数据字典选项（只更新当前选项）")
	public  BaseResult<DataDictionaryDto>   addoption(@RequestBody DataDictionaryDto dataDictionaryDto) throws Exception {
		BaseResult<DataDictionaryDto> baseResult = new BaseResult<DataDictionaryDto>();
		baseResult.setTimestamp(String.valueOf(new Date().getTime()));
		baseResult.setPath(WebUtils.getRequest().getRequestURI());
		try {
			dataDictionaryOptionService.addOptions(dataDictionaryDto);
			baseResult.setStatus("200");
			baseResult.setData(dataDictionaryDto);
		} catch (Exception e) {
			baseResult.setStatus("500");
			baseResult.setMessage(e.getMessage());
		}
		return baseResult;
	}
	
	
	@RequestMapping(value = "/deleteoption/{Id}", method = RequestMethod.POST)
	@ApiOperation("删除数据字典选项")
	public  BaseResult<DataDictionaryOptionDto> deleteoption(@PathVariable(value = "Id")String Id) throws Exception {
		BaseResult<DataDictionaryOptionDto> baseResult = new BaseResult<DataDictionaryOptionDto>();
		baseResult.setTimestamp(String.valueOf(new Date().getTime()));
		baseResult.setPath(WebUtils.getRequest().getRequestURI());
		try {
			dataDictionaryOptionService.delete(Id);
			baseResult.setStatus("200");
		} catch (Exception e) {
			baseResult.setStatus("500");
			baseResult.setMessage(e.getMessage());
		}
		return baseResult;
	}
	
	@RequestMapping(value = "/queryOptionByDicId/{dictionaryId}", method = RequestMethod.POST)
	@ApiOperation("根据数据字典id查询数据字典选项")
	public  List<DataDictionaryOption> queryOptionByDicId(@PathVariable(value = "dictionaryId")String dictionaryId) throws Exception {

		return dataDictionaryOptionService.queryOptionByDicId(dictionaryId);
	}
	@PostMapping("/queryOptionByModel")
	@ApiOperation("根据模块和数据字典标识获取下拉框")
	public Result queryOptionByModel(@RequestBody DataDictionaryDto dataDictionaryDto){
		List<DataDictionaryVo> optionList=dataDictionaryOptionService.getByDictionaryenAndModel(dataDictionaryDto);

		return  Result.ok(optionList);
	}
	@PostMapping("/getAppVersion")
	@ApiOperation("根据不同app获取版本")
	public Result getAppVersion(@RequestBody AppVersionDto appVersionDto){
		AppVersionVo appVersion = dataDictionaryOptionService.getAppVersion(appVersionDto);
		return  Result.ok(appVersion);
	}
}
