package com.ekingwin.bas.cloud.document.model;

import java.text.DecimalFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.time.DateUtils;

import com.ekingwin.bas.cloud.document.DocManagerException;

/**
 * 文档实体
 * @author luffy.li
 *
 */
public class DocModel {
	// 静态map，包含UCM属性与系统字段一一对应关系
	public static Map<String,String> docModelMap = new HashMap<String,String>();
	static 
	{
		docModelMap.put("docId",DocModelConstant.DID);
		docModelMap.put("docName",DocModelConstant.DOCNAME);
		docModelMap.put("revlabel",DocModelConstant.REVLABEL);
		docModelMap.put("docType",DocModelConstant.DOCTYPE);
		docModelMap.put("docTitle",DocModelConstant.DOCTITLE);
		docModelMap.put("docAuthor",DocModelConstant.DOCAUTHOR);
		docModelMap.put("comments",DocModelConstant.COMMENTS);
		docModelMap.put("securityGroup",DocModelConstant.SECURITY_GROUP);
		docModelMap.put("createDate", DocModelConstant.CREATE_DATE);
		docModelMap.put("inDate",DocModelConstant.IN_DATE);
		docModelMap.put("outDate",DocModelConstant.OUT_DATE);
		docModelMap.put("originalName",DocModelConstant.PRIMARYFILE_NAME);
		docModelMap.put("docCreator",DocModelConstant.DOCCREATOR);
		docModelMap.put("folderId", "xCollectionID");
		docModelMap.put("folderPath", "xCollectionPath");
		docModelMap.put("clbraUserList","xClbraUserList");
		docModelMap.put("clbraRoleList","xClbraRoleList");
		docModelMap.put("extendUserList","xExtendUserList");
		docModelMap.put("extendRoleList","xExtendRoleList");
		docModelMap.put("deleteDate","xDeleteDate");
		docModelMap.put("deleter","xDeleter");
		docModelMap.put("fileSize","VaultFileSize");
		docModelMap.put("searchNum","xSearchNum");
		docModelMap.put("readNum","xReadNum");
		docModelMap.put("approvalType", "xApprovalType");
		docModelMap.put("approvalStatus", "xApprovalStatus");
		docModelMap.put("webUrl", "URL");
		docModelMap.put("webExtension", "dWebExtension");
		docModelMap.put("extension", "dExtension");
		docModelMap.put("checkoutUser","xCheckoutUser");		
		docModelMap.put("tags","tags");		
	}
	// 文档编号（唯一）
	private String docId;
	// 内容ID（所有修订版本的docName相同）
	private String docName;
	// 修订版本
	private String revlabel;
	// 文档类型
	private String docType;
	// 标题
	private String docTitle;
	// 上传人
	private String docCreator;
	//作者显示名
	private String docAuthorDis;
	// 作者
	private String docAuthor;
	// 删除人
	private String deleter;
	// 注释
	private String comments;
	// 安全组
	private String securityGroup;
	// 文档主文件
	private String primaryFile;
	//替代文件
    private String alternateFile;
	//文件名称
	private String originalName;
	//创建时间
	private String createDate;
	//检入日期
	private String inDate;
	//检出日期
	private String outDate;
	//删除时间
	private String expiredDate;
	// 历史记录
	private List<DocModel> revisionHistory;
	//组权限列表
	private List<PermissionModel> permissionRoles;
	//用户权限列表
	private List<PermissionModel> permissionUsers;
	//当前用户权限
	private PermissionModel permissionModel;
	// 目录编号
	private String folderId;
	//目录路径
	private String folderPath;
	//文档大小
	private String fileSize;
	//文件信息
	private FileModel fileModel;
	//文档扩展属性
	private HashMap<String, String> attrs;
	//用户访问列表
	private String clbraUserList;
	//组访问列表
	private String clbraRoleList;
	//扩展用户访问列表
	private String extendUserList;
	//扩展组访问列表
	private String extendRoleList;
	//文档被搜索数
	private String searchNum;
	//文档阅读数
	private String readNum;
	//检出&取消检出
	private boolean ischeckout = false;
	//订阅&取消订阅
	private boolean issubscript = false;
	//收藏&取消收藏
	private boolean iscollection = false;
	//收藏主键id
	private String collectionId;
	//审批类型
	private String approvalType;
	//审批状态
	private String approvalStatus;
	//web url
	private String webUrl;
	//下载地址
	private String downloadUrl;
	//web类型
	private String webExtension;
	// 文件类型
	private String extension;
	//检出人
	private String checkoutUser;
	//检出人显示名
	private String checkoutUserName;
	//文档状态
	private String status;
	//文件ID
	private String fileId;
	//发布日期
	private String releaseDate;
	//标签
	private String tags;
	//维度id
	private String folderIds;
	//维度名称
	private String folderName;
	//文号
	private String docno;
	//水印
	private String watermark;
	//提供者
	private String provideruser;
	//权限列表
	private List<DocPermissionDto> permissionList;
	//维度列表
	private List<FolderDocumentDto> folderDocumentList;
	//附件列表
	private List<DocumentChildDto> documentChildList;
	private String  lookover;	 //是否可以知识查看：1：可以；0：不可以
	private String  docupdate;	 //是否可以知识更新：1：可以；0：不可以	
	private String  download;	 //是否可以附件下载：1：可以；0：不可以		
	private String  docdelete;	 //是否可以知识删除：1：可以；0：不可以		
	private String  docprint;	 //是否可以附件打印：1：可以；0：不可以		
	private String  sendlink;	 //是否可以知识分享：1：可以；0：不可以		
	private String  msgnotice;	 //是否可以消息提醒：1：可以；0：不可以	
	private String  revId;		 //版本主键ID
	private Integer sortid;	     // 排序号
	private Integer downSum;//下载量
	private Integer readSum;//阅读量
	private Integer discuss;//评论量
	private Integer collect;//收藏量
	private Integer score;//评分
	private Integer myScore;//我的评分
	private String  oldDocId; //原主文档ID
	private String  oldRevId; //原主文档版本ID
	private String  oldDocName; //原主文档DocName
	private Date createDateParse; 	//转换为date 的创建时间
	private Integer printNum;
	
	//getter && setter

	public Integer getPrintNum() {
		return printNum;
	}
	public void setPrintNum(Integer printNum) {
		this.printNum = printNum;
	}
	public Date getCreateDateParse() {
		if(StringUtils.isNotEmpty(createDate))
			try {
				createDateParse = DateUtils.parseDateStrictly(createDate, "yyyy-MM-dd HH:mm:ss");
			} catch (ParseException e) {
				e.printStackTrace();
			}
		return createDateParse;
	}
	public void setCreateDateParse(Date createDateParse) {
		this.createDateParse = createDateParse;
	}
	public String getOldDocName() {
		return oldDocName;
	}
	public void setOldDocName(String oldDocName) {
		this.oldDocName = oldDocName;
	}
	public String getOldDocId() {
		return oldDocId;
	}
	public void setOldDocId(String oldDocId) {
		this.oldDocId = oldDocId;
	}
	public String getOldRevId() {
		return oldRevId;
	}
	public void setOldRevId(String oldRevId) {
		this.oldRevId = oldRevId;
	}
	public Integer getMyScore() {
		return myScore;
	}
	public void setMyScore(Integer myScore) {
		this.myScore = myScore;
	}
	public Integer getSortid() {
		return sortid;
	}
	public void setSortid(Integer sortid) {
		this.sortid = sortid;
	}
	public String getRevId() {
		return revId;
	}
	public void setRevId(String revId) {
		this.revId = revId;
	}
	public List<FolderDocumentDto> getFolderDocumentList() {
		return folderDocumentList;
	}
	public void setFolderDocumentList(List<FolderDocumentDto> folderDocumentList) {
		this.folderDocumentList = folderDocumentList;
	}
	public List<DocumentChildDto> getDocumentChildList() {
		return documentChildList;
	}
	public void setDocumentChildList(List<DocumentChildDto> documentChildList) {
		this.documentChildList = documentChildList;
	}
	public String getLookover() {
		return lookover;
	}
	public void setLookover(String lookover) {
		this.lookover = lookover;
	}
	public String getDocupdate() {
		return docupdate;
	}
	public void setDocupdate(String docupdate) {
		this.docupdate = docupdate;
	}
	public String getDownload() {
		return download;
	}
	public void setDownload(String download) {
		this.download = download;
	}
	public String getDocdelete() {
		return docdelete;
	}
	public void setDocdelete(String docdelete) {
		this.docdelete = docdelete;
	}
	public String getDocprint() {
		return docprint;
	}
	public void setDocprint(String docprint) {
		this.docprint = docprint;
	}
	public String getSendlink() {
		return sendlink;
	}
	public void setSendlink(String sendlink) {
		this.sendlink = sendlink;
	}
	public String getMsgnotice() {
		return msgnotice;
	}
	public void setMsgnotice(String msgnotice) {
		this.msgnotice = msgnotice;
	}
	public String getProvideruser() {
		return provideruser;
	}
	public void setProvideruser(String provideruser) {
		this.provideruser = provideruser;
	}
	public List<DocPermissionDto> getPermissionList() {
		return permissionList;
	}
	public void setPermissionList(List<DocPermissionDto> permissionList) {
		this.permissionList = permissionList;
	}
	public String getWatermark() {
		return watermark;
	}
	public void setWatermark(String watermark) {
		this.watermark = watermark;
	}
	public String getDocno() {
		return docno;
	}
	public void setDocno(String docno) {
		this.docno = docno;
	}
	public String getDocId() {
		return docId;
	}
	public void setDocId(String docId) {
		this.docId = docId;
	}
	public String getDocName() {
		return docName;
	}
	public void setDocName(String docName) {
		this.docName = docName;
	}
	public String getRevlabel() {
		return revlabel;
	}
	public void setRevlabel(String revlabel) {
		this.revlabel = revlabel;
	}
	public String getDocType() {
		return docType;
	}
	public void setDocType(String docType) {
		this.docType = docType;
	}
	public String getDocTitle() {
		return docTitle;
	}
	public void setDocTitle(String docTitle) {
		this.docTitle = docTitle;
	}
	public String getDocAuthor() {
		return docAuthor;
	}
	public void setDocAuthor(String docAuthor) {
		this.docAuthor = docAuthor;
	}
	public String getComments() {
		return comments;
	}
	public void setComments(String comments) {
		this.comments = comments;
	}
	public String getSecurityGroup() {
		return securityGroup;
	}
	public void setSecurityGroup(String securityGroup) {
		this.securityGroup = securityGroup;
	}
	public String getPrimaryFile() {
		return primaryFile;
	}
	public void setPrimaryFile(String primaryFile) {
		this.primaryFile = primaryFile;
	}
	public String getInDate() {
		return inDate;
	}
	public void setInDate(String inDate) throws DocManagerException {
		try
		{
			if(!StringUtils.isEmpty(inDate))
			{
				Date indate = new Date( ); 
				SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss"); 
				SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss"); 
				String ind= inDate; 
				indate = (Date) formatter.parse(ind); 
				this.inDate = sdf.format(indate);
			}
		}
		catch(Exception ex)
		{
			ex.printStackTrace();
			throw new DocManagerException(ex.getMessage());
		}
	}
	public String getOutDate() {
		return outDate;
	}
	public void setOutDate(String outDate) {
		if(!StringUtils.isEmpty(outDate))
		{
		this.outDate = outDate.replaceAll("Z", "");
		}
	}
	public List<DocModel> getRevisionHistory() {
		return revisionHistory;
	}
	public void setRevisionHistory(List<DocModel> revisionHistory) {
		if(this.revisionHistory != null)
		{
			this.revisionHistory = revisionHistory;
		}
		else
		{
			this.revisionHistory = new ArrayList<DocModel>();
			this.revisionHistory = revisionHistory;
		}
	}
	public List<PermissionModel> getPermissionRoles() {
		return permissionRoles;
	}
	public void setPermissionRoles(List<PermissionModel> permissionRoles) {
		this.permissionRoles = permissionRoles;
	}
	public List<PermissionModel> getPermissionUsers() {
		return permissionUsers;
	}
	public void setPermissionUsers(List<PermissionModel> permissionUsers) {
		this.permissionUsers = permissionUsers;
	}
	public String getFolderId() {
		return folderId;
	}
	public void setFolderId(String folderId) {
		this.folderId = folderId;
	}
	public String getFileSize() {
		if(!StringUtils.isEmpty(fileSize))
		{
			int size = Integer.parseInt(fileSize);
			float result = (float)size/1024;
			DecimalFormat df = new DecimalFormat("0.00");//格式化小数，不足的补0
			  if(result > 0.01)
			  {
				  return df.format(result)+"KB";
			  }
			  else
			  {
				  return "0.01KB";
			  }
		}
		return "";
	}
	public String getRealFileSize() {
		return fileSize;
	}
	public void setFileSize(String fileSize) {
		this.fileSize = fileSize;
	}
	public FileModel getFileModel() {
		return fileModel;
	}
	public void setFileModel(FileModel fileModel) {
		this.fileModel = fileModel;
	}
	public HashMap<String, String> getAttrs() {
		if(this.attrs != null)
		{
			return this.attrs;
		}
		else
		{
			this.attrs = new HashMap<String, String>();
			return this.attrs;
		}
	}
	
	public void setAttrs(HashMap<String, String> attrs) {
		if(this.attrs != null)
		{
			this.attrs = attrs;
		}
		else
		{
			this.attrs = new HashMap<String, String>();
			this.attrs = attrs;
		}
	}
	
	public void putAttrsMap(String key, String value) {
		this.getAttrs().put(key, value);
	}
	
	public PermissionModel getPermissionModel() {
		return permissionModel;
	}
	public void setPermissionModel(PermissionModel permissionModel) {
		this.permissionModel = permissionModel;
	}
	public String getOriginalName() {
		return originalName;
	}
	public void setOriginalName(String originalName) {
		this.originalName = originalName;
	}
	public String getCreateDate() {
		return createDate;
	}
	public void setCreateDate(String createDate) {
		this.createDate = createDate.replaceAll("Z", "");
	}
	public String getDocCreator() {
		return docCreator;
	}
	public void setDocCreator(String docCreator) {
		this.docCreator = docCreator;
	}
	public String getClbraUserList() {
		return clbraUserList;
	}
	public void setClbraUserList(String clbraUserList) {
		this.clbraUserList = clbraUserList;
	}
	public String getClbraRoleList() {
		return clbraRoleList;
	}
	public void setClbraRoleList(String clbraRoleList) {
		this.clbraRoleList = clbraRoleList;
	}
	public String getExtendUserList() {
		return extendUserList;
	}
	public void setExtendUserList(String extendUserList) {
		this.extendUserList = extendUserList;
	}
	public String getExtendRoleList() {
		return extendRoleList;
	}
	public void setExtendRoleList(String extendRoleList) {
		this.extendRoleList = extendRoleList;
	}
	public String getFolderPath() {
		return folderPath;
	}
	public void setFolderPath(String folderPath) {
		this.folderPath = folderPath;
	}
	public String getDeleter() {
		return deleter;
	}
	public void setDeleter(String deleter) {
		this.deleter = deleter;
	}

	public String getExpiredDate() {
		return expiredDate;
	}
	public void setExpiredDate(String expiredDate) {
		this.expiredDate = expiredDate;
	}
	public String getSearchNum() {
		return searchNum;
	}
	public void setSearchNum(String searchNum) {
		this.searchNum = searchNum;
	}
	public String getReadNum() {
		return readNum;
	}
	public void setReadNum(String readNum) {
		this.readNum = readNum;
	}
	public boolean isIscheckout() {
		return ischeckout;
	}
	public void setIscheckout(boolean ischeckout) {
		this.ischeckout = ischeckout;
	}
	public boolean isIssubscript() {
		return issubscript;
	}
	public void setIssubscript(boolean issubscript) {
		this.issubscript = issubscript;
	}
	public boolean isIscollection() {
		return iscollection;
	}
	public void setIscollection(boolean iscollection) {
		this.iscollection = iscollection;
	}
	public String getCollectionId() {
		return collectionId;
	}
	public void setCollectionId(String collectionId) {
		this.collectionId = collectionId;
	}
	public String getApprovalType() {
		return approvalType;
	}
	public void setApprovalType(String approvalType) {
		this.approvalType = approvalType;
	}
	public String getApprovalStatus() {
		return approvalStatus;
	}
	public void setApprovalStatus(String approvalStatus) {
		this.approvalStatus = approvalStatus;
	}
	public String getDocAuthorDis() {
		return docAuthorDis;
	}
	public void setDocAuthorDis(String docAuthorDis) {
		this.docAuthorDis = docAuthorDis;
	}

	public String getAlternateFile() {
		return alternateFile;
	}
	public void setAlternateFile(String alternateFile) {
		this.alternateFile = alternateFile;
	}
	public String getWebUrl() {
		return webUrl;
	}
	public void setWebUrl(String webUrl) {
		this.webUrl = webUrl;
	}
	public static Map<String, String> getDocModelMap() {
		return docModelMap;
	}
	public static void setDocModelMap(Map<String, String> docModelMap) {
		DocModel.docModelMap = docModelMap;
	}
	public String getWebExtension() {
		return webExtension;
	}
	public void setWebExtension(String webExtension) {
		this.webExtension = webExtension;
	}
	public String getCheckoutUser() {
		return checkoutUser;
	}
	public void setCheckoutUser(String checkoutUser) {
		this.checkoutUser = checkoutUser;
	}
	public String getCheckoutUserName() {
		return checkoutUserName;
	}
	public void setCheckoutUserName(String checkoutUserName) {
		this.checkoutUserName = checkoutUserName;
	}
	public String getExtension() {
		return extension;
	}
	public void setExtension(String extension) {
		this.extension = extension;
	}
	public String getStatus() {
		return status;
	}
	public void setStatus(String status) {
		if("RELEASED".equals(status))
		{
			this.status = "生效";
		}
		else if("EXPIRED".equals(status))
		{
			this.status = "失效";
		}
		else if("DONE".equals(status))
		{
			this.status = "未生效";
		}
		else
		{
			this.status = "解析中";
		}
		
	}
	public String getDownloadUrl() {
		return downloadUrl;
	}
	public void setDownloadUrl(String downloadUrl) {
		this.downloadUrl = downloadUrl;
	}
	public String getReleaseDate() {
		return releaseDate;
	}
	public void setReleaseDate(String releaseDate) {
		this.releaseDate = releaseDate;
	}
	public String getTags() {
		return tags;
	}
	public void setTags(String tags) {
		this.tags = tags;
	}
	public String getFolderIds() {
		return folderIds;
	}
	public void setFolderIds(String folderIds) {
		this.folderIds = folderIds;
	}
	public String getFolderName() {
		return folderName;
	}
	public void setFolderName(String folderName) {
		this.folderName = folderName;
	}
	public String getFileId() {
		return fileId;
	}
	public void setFileId(String fileId) {
		this.fileId = fileId;
	}
	public Integer getDownSum() {
		return downSum;
	}
	public void setDownSum(Integer downSum) {
		this.downSum = downSum;
	}
	public Integer getReadSum() {
		return readSum;
	}
	public void setReadSum(Integer readSum) {
		this.readSum = readSum;
	}
	public Integer getDiscuss() {
		return discuss;
	}
	public void setDiscuss(Integer discuss) {
		this.discuss = discuss;
	}
	public Integer getCollect() {
		return collect;
	}
	public void setCollect(Integer collect) {
		this.collect = collect;
	}
	public Integer getScore() {
		return score;
	}
	public void setScore(Integer score) {
		this.score = score;
	}
}
