package com.ekingwin.bas.cloud.document.service;

import java.io.File;
import java.io.InputStream;
import java.util.Map;

import org.springframework.http.ResponseEntity;

import com.ekingwin.bas.cloud.document.UAttachementException;
import com.ekingwin.bas.cloud.document.dto.UploadFileObject;
import com.ekingwin.bas.cloud.document.dto.UploadFileDto;

/**
 * 附件管理接口，该接口定义了文件的上传、下载等功能；该接口是附件管理组件的总入口，所有对于附件的操作都需要通过该接口实现
 * @author chenjb
 *
 */
public interface IIAttachmentService{
	


	/**
	 * 下载文件
	 * @param id	文件ID
	 * @return FileObject	下载的文件对象
	 * @throws UAttachementException
	 */
	public UploadFileObject downloadFile(String id) throws UAttachementException;
	/**
	 * 下载文件
	 * @param id	文件ID
	 * @return FileObject	下载的文件对象
	 * @throws UAttachementException
	 */
	public ResponseEntity<byte[]> downloadFileByte(String id) throws UAttachementException;
	
	/**
	 * 文件上传
	 * @param file 上传的文件对象
	 * @param fileName 上传的文件名
	 * @param fileMeta 上传文件时，文件的额外元数据
	 * @return UploadFile 上传后的文件对象
	 * @throws UAttachementException
	 */
	public UploadFileDto upload(File file, String fileName, Map<String, String[]> fileMeta) throws UAttachementException;

	
	/**
	 * 删除文件
	 * @param id	文件ID
	 * @throws UAttachementException
	 */
	public void deleteFile(String id) throws UAttachementException;

	/**
	 * 批量下载文件
	 * @param ids	文件的ID数组
	 * @return		下载的文件对象（批量文件已经被打包为一个压缩包）
	 * @throws UAttachementException
	 */
	public UploadFileObject downloadFileBatch(String[] ids) throws UAttachementException;

	/**
	 * 批量下载文件
	 * @param ids	文件的ID数组
	 * @return		下载的文件对象（批量文件已经被打包为一个压缩包）
	 * @throws UAttachementException
	 */
	public ResponseEntity<byte[]> downloadFileBatchByte(String[] ids) throws UAttachementException;
	
	public UploadFileDto upload(InputStream inputStream, String name, Map<String, String[]> fileMeta) throws UAttachementException;
	
	/**
	 * 文件预览的下载地址
	 * @param id
	 * @param b
	 * @return
	 */
	public ResponseEntity<byte[]> downloadFileByte(String id, boolean b) throws UAttachementException;

}
