package com.ekingwin.bas.cloud.document.service;

import java.io.InputStream;
import java.util.List;
import java.util.Map;

import org.omg.CORBA.UserException;

import com.ekingwin.bas.cloud.document.dto.UploadFileObject;
import com.ekingwin.bas.cloud.document.dto.UploadUserDto;
import com.ekingwin.bas.cloud.infra.dto.QueryDTO;
import com.ekingwin.bas.cloud.infra.dto.SaveResultDTO;
import com.ekingwin.bas.cloud.infra.service.IBaseEntityService;
import com.ekingwin.bas.cloud.infra.utils.db.PageCriteria;

/**
 * 定义用户基本信息以及其操作的接口，包括了对于用户的基本增删改查的操作
 * @author chenjb
 *
 */
public interface IUserService extends IBaseEntityService<UploadUserDto> {

	public UploadFileObject exportsUser(QueryDTO query) throws UserException;
	
	public UploadFileObject importsUser(InputStream in) throws UserException;
	
	public PageCriteria<UploadUserDto> queryUsersInOrg(QueryDTO query) throws UserException;
	
	public PageCriteria<UploadUserDto> getUsersByNotBen(QueryDTO query) throws UserException;
	public PageCriteria<UploadUserDto> getParentUserById(QueryDTO query) throws UserException;
	
	public PageCriteria<UploadUserDto> getUsersByUser(QueryDTO query) throws UserException;


	/**
	 * 用户初始化推送（勿乱调）
	 * @throws UserException 
	 */
	public void initializationUserPush() throws UserException;
	
	public List<UploadUserDto> getAllUserByOrg(String orgid) throws UserException;
	
	/**
	 * 修改idm密码
	 * @param userId
	 * @param oldPassword
	 * @param newPassword
	 * @throws UserException 
	 */
	public SaveResultDTO changePassword(String userId, String oldPassword,
			String newPassword) throws UserException;
	/**
	 * 获取邮件未读数
	 * @return
	 * @throws Exception
	 */
	public int getMailNewcount() throws Exception ;
	/**
	 * 获取邮箱的登陆地址
	 * @return
	 * @throws Exception
	 */
	public String getMailUrl() throws Exception ;
	
	
	/**
	 * 根据用户id判断用户是否是超级管理员
	 * @param userid
	 * @return
	 */
	public int judgeAdminByUserId(String userid);

	/**
	 * 批量重置密码
	 * @param list
	 * @throws UserException 
	 */
	public void resetPassword(List<String> list) throws UserException;

	/**
	 * 根据手机号码保存密码
	 * @param map
	 */
	public SaveResultDTO modifyPasswordByPhone(Map<String, String> map);

	/**
	 * 根据邮箱保存密码
	 * @param map
	 */
	public SaveResultDTO modifyPasswordByEmail(Map<String, String> map);
	
	/**
	 * 用户的OUD推送接口
	 * @param userDto
	 * @param empuid
	 * @param iden
	 * @throws UserException
	 */
	public void callIDM(UploadUserDto userDto,String empuid,int iden) throws UserException;

	
	public boolean deleteAccountByAccAndSyscode(String account, String syscode);

	public void pushDataIDMSeven(UploadUserDto userDto);

	/**
	 * 校验验证的的正确性及有效性
	 * @param account
	 * @param code
	 * @throws UserException 
	 */
	public boolean validationCodeValidity(String account, String code) throws UserException;
	/**
	 * 通过手机号获取用户信息
	 * @param mobile
	 * @return
	 * @throws UserException
	 */
	public UploadUserDto getUserByMobile(String mobile) throws UserException;

	/**
	 * 分页查询
	 * @param query
	 * @return
	 * @throws UserException 
	 */
	public PageCriteria<UploadUserDto> queryList(QueryDTO query, String logid, int flag) throws UserException;

	/**
	 * 根据用户id获取兼岗信息并在一个String里，号隔开
	 * @param empuid
	 * @return
	 * @throws UserException 
	 */
	public String getAndPostByUserid(String empuid) throws UserException;

	/**
	 * 根据用户id获取用户信息（包含主岗岗位全路径）
	 * @param userId
	 * @return
	 */
	public UploadUserDto getUserInfo(String userId);

	
}
