package com.ekingwin.bas.cloud.document.service.impl;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import com.ekingwin.bas.cloud.document.UAttachementException;
import com.ekingwin.bas.cloud.document.dto.UploadFileObject;
import com.ekingwin.bas.cloud.document.dto.UploadUserDto;
import com.ekingwin.bas.cloud.document.model.DocModel;
import com.ekingwin.bas.cloud.document.model.FileModel;
import com.ekingwin.bas.cloud.document.service.IDocService;
import com.ekingwin.bas.cloud.document.service.IIDownloadService;
import com.ekingwin.bas.cloud.document.service.IUserService;
import com.ekingwin.bas.cloud.document.utils.DownloadUtils;
import com.ekingwin.bas.cloud.infra.exception.BasException;
import com.ekingwin.bas.cloud.infra.utils.web.UserUtils;

@Service(value = "commonDownloadService")
public class CommonDownloadServiceImpl implements IIDownloadService {

	private Logger logger = LoggerFactory.getLogger(this.getClass());

	@Autowired
	private IDocService docService;
	@Autowired
	@Qualifier(value = "userServiceImpl")
	private IUserService userManager;

	// 根据文件ID下载
	public UploadFileObject downloadFile(String id) throws UAttachementException {
		if (StringUtils.isNotEmpty(id)) {
			// 从UCM中获取UCM文件对象
			UploadUserDto user = getCurrentUser();
			DocModel docModel = docService.getDocModelBydID(user, id);
			FileModel paramFileModel = new FileModel();
			// //从UCM中获取文件流对象
			paramFileModel = docService.getPrimaryFileBydID(user, id, docModel.getDocTitle(), paramFileModel);

			// 将UCM中获取的文件信息以及文件流封装为FileObject对象
			UploadFileObject fo = new UploadFileObject();
			fo.setId(id);
			fo.setName(paramFileModel.getFileName());
			fo.setSize(Long.valueOf(paramFileModel.getFileSize()));
			fo.setType(paramFileModel.getFileExtension());
			fo.setStream(paramFileModel.getInputStream());
			return fo;
		} else {
			throw new UAttachementException("当前附件的ID为空");
		}
	}

	private UploadUserDto getCurrentUser() throws UAttachementException{
		UploadUserDto user = null;
		try {
			user = userManager.get(UserUtils.getCurrentUser());
		} catch (BasException e) {
			logger.error(e.getMessage(), e);
			throw new UAttachementException(e);
		}
		return user;
	}

	@Override
	public ResponseEntity<byte[]> downloadFileByte(String id) throws UAttachementException {
		UploadFileObject fo = this.downloadFile(id);
		try {
			return DownloadUtils.download(fo);
		} catch (Exception e) {
			logger.error(e.getMessage());
			throw new UAttachementException(e);
		}
	}

	@Override
	public ResponseEntity<byte[]> downloadFileByte(String id, boolean b) throws UAttachementException{
		UploadFileObject fo = this.downloadFile(id,b);
		try {
			return DownloadUtils.download(fo);
		} catch (Exception e) {
			logger.error(e.getMessage());
			throw new UAttachementException(e);
		}
	}
	
	// 根据文件ID下载；预览用
	public UploadFileObject downloadFile(String id, boolean b) throws UAttachementException {
		if (StringUtils.isNotEmpty(id)) {
			UploadUserDto user = null;
			DocModel docModel = docService.getDocModelBydID(user, id);
			FileModel paramFileModel = new FileModel();
			if("1".equals(docModel.getWatermark()))
				paramFileModel.setWatermark(true);
			// //从UCM中获取文件流对象
			paramFileModel = docService.getPrimaryFileBydID(user, id, docModel.getDocTitle(), paramFileModel);

			// 将UCM中获取的文件信息以及文件流封装为FileObject对象
			UploadFileObject fo = new UploadFileObject();
			fo.setId(id);
			fo.setName(paramFileModel.getFileName());
			fo.setSize(Long.valueOf(paramFileModel.getFileSize()));
			fo.setType(paramFileModel.getFileExtension());
			fo.setStream(paramFileModel.getInputStream());
			return fo;
		} else {
			throw new UAttachementException("当前附件的ID为空");
		}
	}

}
