package com.ekingwin.bas.cloud.document.service.impl;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;

import com.ekingwin.bas.cloud.document.UAttachementException;
import com.ekingwin.bas.cloud.document.DocManagerException;
import com.ekingwin.bas.cloud.document.dao.ManagementCenterDao;
import com.ekingwin.bas.cloud.document.dao.entity.ManagementCenter;
import com.ekingwin.bas.cloud.document.dto.DocumentImageDto;
import com.ekingwin.bas.cloud.document.dto.ManagementCenterDto;
import com.ekingwin.bas.cloud.document.dto.UploadUserDto;
import com.ekingwin.bas.cloud.document.model.DocModel;
import com.ekingwin.bas.cloud.document.service.IIAttachmentService;
import com.ekingwin.bas.cloud.document.service.IDocService;
import com.ekingwin.bas.cloud.document.service.IManagementCenterService;
import com.ekingwin.bas.cloud.document.service.IUserService;
import com.ekingwin.bas.cloud.infra.dto.QueryDTO;
import com.ekingwin.bas.cloud.infra.exception.BasException;
import com.ekingwin.bas.cloud.infra.service.BaseService;
import com.ekingwin.bas.cloud.infra.utils.db.PageCriteria;
import com.ekingwin.bas.cloud.infra.utils.web.UserUtils;

@Primary
@Service
public class ManagementCenterServiceImpl extends BaseService implements IManagementCenterService{

	@Autowired
	private ManagementCenterDao managementCenterDao;
	@Autowired
	@Qualifier(value = "userServiceImpl")
	private IUserService userManager;
	
	
	@Autowired
	private IDocService docService;
	
	@Autowired
	private DocumentImageServiceImpl documentImageService;
	

	
	
	
	
	private Logger logger = LoggerFactory.getLogger(this.getClass());
	
	@Autowired
	private IIAttachmentService attachmentManager;
	
	@Value("${document.docStoreLocation}")
	private String uploadUrl;//#附件存储地址
	
	@Value("${document.imagepath}")
	private String imagepath;//#图片读取路径  门户图片直接读取物理地址
	
	@Value("${shareNewspath}")
	private String shareNewspath;//#控股新闻存储路径  重庆医药使用-可用于外网门户
	
	@Value("${shareNewsUrl}")
	private String shareNewsUrl;//#控股新闻访问路径 前端相对路径
	
	@Value("${kgmhService}")
	private String kgmhService;//#控股服务器地址IP
	
	@Value("${domainName}")
	private String domainName;// 门户服务地址-富文本框中图片 发到外网地址替换使用
	
	@Value("${kgport}")
	private String kgport;//#控股服务器地址端口
	
	@Value("${newreleaseprocess}")
	private String newreleaseprocess; //#新闻发布是否需要审批流程
	
	@Value("${externalportal}")
	private String externalportal; //#是否有外部门户
	
	@Override
	public boolean save(ManagementCenterDto object) throws BasException {
		// TODO Auto-generated method stub
		return false;
	}

	@Override
	public boolean delete(String id) throws BasException {
		try {
			managementCenterDao.deleteDocById(id);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return true;
	}

	@Override
	public PageCriteria<ManagementCenterDto> query(QueryDTO query)
			throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public ManagementCenterDto get(String id) throws BasException {
		ManagementCenterDto managementCenterDto = new ManagementCenterDto();
		try {
			ManagementCenter managementCenter = managementCenterDao.getDocInfoByDocid(id);
			super.commonBuild(managementCenterDto, managementCenter);
		} catch (Exception e) {
			throw new BasException();
		}
		return managementCenterDto;
		
	}

	
	
	
	/**
	 * 文档检入
	 * @param file
	 * @param fileName
	 * @param attrs
	 * @return
	 * @throws UAttachementException
	 * @throws DocManagerException
	 */
	public DocModel checkIn(File file, String fileName, HashMap<String, String> attrs) throws UAttachementException, DocManagerException{
		//初始化文件对象
		DocModel docModel = new DocModel();
		UploadUserDto user = getCurrentUser();
		//如果文档ID为空，则检入新文档
		docModel.setDocTitle(fileName);
		docModel.setOriginalName(fileName);
		docModel.setAttrs(attrs);
		docModel.setPrimaryFile(file.getPath());
		docModel=docService.checkIn(user, docModel);
		return docModel;
	}
	/**
	 * 获取当前用户
	 * @return
	 * @throws UAttachementException
	 */
	private UploadUserDto getCurrentUser() throws UAttachementException{
		UploadUserDto user = null;
		try {
			user = userManager.get(UserUtils.getCurrentUser());
		} catch (BasException e) {
			logger.error(e.getMessage(), e);
			throw new UAttachementException(e);
		}
		return user;
	}
	
	
	/**
	 * 内容转化为Html
	 * @param content
	 * @param fileName
	 * @param attrs
	 * @return
	 * @throws DocManagerException
	 */
	@Override
	public DocModel contentsToHtml(String content, String fileName,  HashMap<String, String> attrs) throws DocManagerException{
		DocModel docModel = null;
		PrintWriter pw = null;
		try {
			File file = new File(uploadUrl);
			if (!file.exists()) {
				file.mkdir();
			}
			String filename = uploadUrl + File.separator +UserUtils.getCurrentUser()+ fileName + "_" + System.currentTimeMillis() + "." + "html";
			File docFile = new File(filename);
			
			try {
				pw = new PrintWriter(docFile);
			} catch (FileNotFoundException e) {
				e.printStackTrace();
			}
			pw.print(content);
			pw.close();
			docModel = checkIn(docFile, fileName, attrs);
			File docFile2 = new File(filename);
			docFile2.delete();
		} catch (UAttachementException e) {
			if(pw!=null){
				pw.close();
			}
			e.printStackTrace();
		}
		return docModel;
	}

	
	public DocModel Updatecontents(String content, String docid) throws DocManagerException{
		DocModel docModel = null;
		PrintWriter pw = null;
		try {
			String filepath = "";
			List<Map<String, String>> list= managementCenterDao.getFilePath(docid);
			if(list.size()>0){
				filepath = list.get(0).get("PATH");
				File docFile2 = new File(filepath);
				docFile2.delete();
				File docFile = new File(filepath);
				try {
					pw = new PrintWriter(docFile);
				} catch (FileNotFoundException e) {
					e.printStackTrace();
				}
				pw.print(content);
				pw.close();
			}
		} catch (Exception e) {
			if(pw!=null){
				pw.close();
			}
			e.printStackTrace();
		}
		return docModel;
	}
	@Override
	public String getContentsByDocid(String docid) throws DocManagerException {
		FileInputStream fis = null;
		String contents = "";
		try {
			String path = managementCenterDao.getPathByDocid(docid);
			path = "E:\\file\\portal\\a04c19b3-d55e-4d4a-9537-9264d208defe";
			if(path!=null){
				File file = new File(path);
				fis = new FileInputStream(file);
				
				InputStreamReader reader = new InputStreamReader(fis,"UTF-8"); //最后的"GBK"根据文件属性而定，如果不行，改成"UTF-8"试试
	            BufferedReader br = new BufferedReader(reader);
	            String line="";
	            while ((line = br.readLine()) != null) {
	            	contents+=line;
	            }
	            br.close();
	            reader.close();
			}
		} catch (Exception e) {
			// TODO: handle exception
		}finally{
			if(fis!=null){
				try {
					fis.close();
				} catch (IOException e) {
					logger.info("IOException", e);
				}
			}
		}
		return contents;
	}

	@Override
	public DocumentImageDto saveDocumentImage(String docid)
			throws DocManagerException {
		DocumentImageDto documentImageDto = new DocumentImageDto();
		//获取图片信息
		Map<String, String> fileInfo= managementCenterDao.getFileInfo(docid);
		Date indate = new Date( ); 
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy"); 
		//按年存储
		String year = sdf.format(indate);
		//新的存储路径
		String newpath = uploadUrl +"/image/"+year;
		File dir  = new File(newpath);
		if (!dir.exists()) {
			dir.mkdirs();
		}
		if(fileInfo!=null){
			//获取图片的存储时的文件名
			String newname = fileInfo.get("newname");
			String fileid = fileInfo.get("id");
			//获取原名称
			String originalname = fileInfo.get("originalname");
			//格式
			String extension = fileInfo.get("extension");
			//存储路径
			String location = fileInfo.get("location");
			if(location!=null){
				FileInputStream fis = null;
				FileOutputStream fos = null;
				//新的图片存储路径 
				newpath += "/"+fileid+"."+extension;
				//图片读取路径
				String url = imagepath+"/"+year+"/"+fileid+"."+extension;
				try {
					//图片转存
					fis = new FileInputStream(location+"/"+newname);
					File image = new File(newpath);
					if(!image.exists()){
						fos = new FileOutputStream(image);
						byte[] buf = new byte[1024*10];
						int len = -1;
						while((len = fis.read(buf))!=-1){
							fos.write(buf, 0, len);
						}
						fis.close();
						fos.close();
						documentImageDto.setId(docid);
						documentImageDto.setFileid(fileid);
						documentImageDto.setLocation(newpath);
						documentImageDto.setUrl(url);
						documentImageDto.setType(extension);
						documentImageDto.setName(originalname);
						documentImageService.save(documentImageDto);
					}
					
				} catch (Exception e) {
					// TODO: handle exception
				}finally{
					if(fis!=null){
						try {
							fis.close();
						} catch (IOException e) {
							logger.info("IOException", e);
						}
					}
					if(fos!=null){
						try {
							fos.close();
						} catch (IOException e) {
							logger.info("IOException", e);
						}
					}
				}
			}
		}
		return documentImageDto;
	}
	
	
	@Override
	public void release(String docid,String type) throws BasException {

		
	}
	
	public void releaseShareNews(String docid,String folderid,String type) throws BasException {}
	
	private String dealWithContentImage(String content,String year,String newImagePath) throws BasException{
		String result = content;
		String imageNewUrl =  shareNewsUrl+"/image/"+year;
		String  newimagepath = domainName+imagepath;
		if(result!=null){
			while(result.contains(newimagepath)){
				int index = result.indexOf(newimagepath);
				if(result.length()>index+newimagepath.length()+43){
					String src = result.substring(index, index+newimagepath.length()+42);
					String id = src.substring(src.length()-36,src.length()-4);
					
					if(id!=null){
						DocumentImageDto documentImageDto = documentImageService.get(id);
						String imageLocation = documentImageDto.getLocation();
						String imageType = documentImageDto.getType();
						String contentImageUrl =imageNewUrl+ "/"+id+"."+imageType;
						//图片的复制
						String command1 = "scp -P 2221 "+imageLocation+" "+kgmhService+":"+newImagePath ;
					    try {
					    	createDir(command1);
					    	result = result.replace(src, contentImageUrl);
						} catch (Exception e) {
							// TODO Auto-generated catch block
							e.printStackTrace();
						}
					    
					}
					
					
					logger.info(src);
				}
			}
		}
		return result;
	}
	/**
	 * 创建文件夹/文件
	 * @param folderid
	 * @throws BasException
	 */
	private void createDir(String command1) throws BasException{
		Process process =null;
		String[] kgports = kgport.split(",");
		for(int i = 0 ; i < kgports.length ; i++ ){
			String newkgport = kgports[i] ;
			String command2 = command1.replaceAll("2221", newkgport);
		    try {
		    	logger.info(command2);
				process = Runtime.getRuntime().exec(command2);
				process.waitFor();
				int exitValue = process.exitValue();
				logger.info(command2+"-------------------"+exitValue);
				if(exitValue==1){
					throw new BasException("复制执行失败！");
				}
			} catch (Exception e) {
				e.printStackTrace();
				throw new BasException();
			}
		}
	}
	
	//创建列表
	public void createPageList(String folderid) throws BasException{}

	private void createKgHomeNewsList() throws BasException{}
	
	
	private void createKgHomeBulletinList() throws BasException{}
	
	@Override
	public void updateStatus(ManagementCenterDto managementCenterDto) throws DocManagerException {
		try {
			String docidStr = managementCenterDto.getId();
			if(docidStr!=null){
				String[] docids = docidStr.split(",");
				for(int i = 0 ; i < docids.length ; i++ ){
					String docid = docids[i];
					managementCenterDao.updateStatus(docid, managementCenterDto.getStatus());
				}
				
				
			}
		} catch (Exception e) {
			throw new DocManagerException("更新状态失败!");
		}
	}

	
	private String objToString(Object obj){
		if(obj!=null){
			return obj.toString();
		}else{
			return "";
		}
	}

	@Override
	public List<ManagementCenterDto> homeshowquery() throws DocManagerException {
		List<ManagementCenterDto> result = new ArrayList<ManagementCenterDto>();
		List<ManagementCenter> homeshowquery = managementCenterDao.homeshowquery();
		for(int i = 0 ; i < homeshowquery.size() ; i++ ){
			ManagementCenterDto managementCenterDto = new ManagementCenterDto();
			try {
				super.commonBuild(managementCenterDto, homeshowquery.get(i));
				result.add(managementCenterDto);
			} catch (Exception e) {
			}
		}
		return result;
	}
	
	
	@Override
	public boolean judgmentDelete(String folderid) throws Exception {
		List<Map<String, Object>> queryList = managementCenterDao.judgmentDelete(folderid);
		if(queryList.size()>0){
			Object count = queryList.get(0).get("C");
			if("0".equals(count.toString())){
				return true ;
			}
		}
		return false ;
	}

	

	@Override
	public void updateCreateBy(String docid) {
		String userId = UserUtils.getCurrentUser();
		managementCenterDao.updateCreateBy(docid,userId);
	}

	@Override
	public PageCriteria<ManagementCenterDto> query(QueryDTO query, String folderid) throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public PageCriteria<ManagementCenterDto> queryMyNotice(QueryDTO query) throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public void updateStatusNew(ManagementCenterDto managementCenterDto) throws DocManagerException {
		// TODO Auto-generated method stub
		
	}

	@Override
	public PageCriteria<ManagementCenterDto> publicationQuery(QueryDTO query) throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public PageCriteria<ManagementCenterDto> queryReleased(QueryDTO query) throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public PageCriteria<ManagementCenterDto> queryReleasedByType(QueryDTO query, String type) throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public PageCriteria<ManagementCenterDto> enterpriseActivityQuery(QueryDTO query) throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public List<Map<String, String>> getDeleteDocFolderid(String docids, String folderid, String type)
			throws BasException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public void pushNewsOrNoticeToJd(String docid, String type) throws Exception {
		// TODO Auto-generated method stub
		
	}


	
}
