package com.ekingwin.bas.cloud.org.dao;

import java.util.List;
import java.util.Map;

import org.apache.ibatis.annotations.Param;

import tk.mybatis.mapper.entity.Example;

import com.ekingwin.bas.cloud.org.OrganizationException;
import com.ekingwin.bas.cloud.org.dao.entity.Organization;
import com.ekingwin.bas.cloud.org.dao.entity.OrganizationTree;
import com.ekingwin.bas.cloud.org.dao.entity.ViewUserPost;
import com.ekingwin.bas.cloud.org.dto.OrganizationTreePostDto;
import com.ekingwin.bas.mapper.BasMapper;

public interface IOrganizationDao extends BasMapper<Organization> {
	/**
	 * 获取指定用户的岗位信息
	 * @param userId
	 * @return
	 */
	public List<Organization> getUserPost(String userId);
	
	
	/**
	 * 获取指定用户的部门信息
	 * @param userId
	 * @return
	 */
	public Organization getUserDept(String userId);
	
	/**
	 * 根据code获取组织机构信息
	 * @param code
	 * @return
	 */
	public Organization getOrganizaitonByCode(String code);
	
	public String getIdByCode(String code);
	
	public String getCodeByCode(String code);
	
	//状态删除
	public void deleteById(String id); 
	
	//查询第一级组织树
	public List<OrganizationTree> selectFirstTree(@Param("userid1")String userid1,@Param("userid2")String userid2  );
	
	//查询所有父级树
    public List<OrganizationTree> getPartentTree(String id);
    //根据id查询所有下一级组织树
    public List<OrganizationTree> getChildTreeById(String id);
    //根据id查询所有下级组织树
    public List<OrganizationTree> getAllChildTree(String id);
    
    public List<Map<String, Object>> getPostById(String userid);
    public List<ViewUserPost> queryPostById(@Param("example")Example example,@Param("userid")String userid);


	public String getOrgIdsByUserId(String userId);


	public List<OrganizationTreePostDto> getPostByOrgid(@Param("logid")String logid, @Param("orgid")String orgid);


	/**
	 * 校验组织编码的唯一性
	 * @param code
	 * @return
	 */
	public int judgeOrgCodeByCode(@Param("code")String code);


	/**
	 * 超级管理员获取菜单？
	 * @param orgid
	 * @return
	 */
	public List<OrganizationTreePostDto> getPostAll(@Param("orgid")String orgid);

	/**
	 * 根据岗位id获取岗位全路径
	 * @param postid
	 * @return
	 */
	public String getPostRouteByPostid(@Param("postid")String postid);
	
	/**
	 * 根据父ID，获取下一个treecode
	 * @param pid
	 * @return
	 */
	public String getNextTreeCodeByPid(@Param("pid")String pid);
	
	/**
	 * 根据ID，获取treecode
	 * @param id
	 * @return
	 */
	public String getTreeCodeById(@Param("id")String id);
	
	/**
	 * 根据父ID，获取所有的子ID,包含自己本身的ID
	 * @param pid
	 * @return
	 */
	public String getSubIdByPid(@Param("pid")String pid);
	/**
	 * 根据全部的子ID更新状态为删除
	 * @param subid
	 * @return
	 */
	public void deleteBySubId(@Param("subid")String subid);
	
	public List<Map<String, Object>> getUsersByOrg(@Param("example")Example example,@Param("orgid")String orgid);
	
	public List<Map<String, Object>> getOrgByEmpid(@Param("example")Example example,@Param("orgid")String orgid);
	
	/**
	 * 批量更新
	 * @param updateList
	 * @throws OrganizationException
	 */
	public void batchUpdate(List<Organization> updateList);
	/**
	 * 批量新增
	 * @param insertList
	 */
	public void batchInsert(List<Organization> insertList) ;
	
	public List<Map<String, Object>> getUserByOrg(@Param("example")Example example,@Param("orgid")String orgid);
}
