package com.ekingwin.bas.cloud.org.service.impl;

import com.ekingwin.bas.cloud.infra.dto.BaseResult;
import com.ekingwin.bas.cloud.infra.dto.QueryDTO;
import com.ekingwin.bas.cloud.infra.exception.BasException;
import com.ekingwin.bas.cloud.infra.service.BaseService;
import com.ekingwin.bas.cloud.infra.utils.common.ResultUtils;
import com.ekingwin.bas.cloud.infra.utils.db.PageCriteria;
import com.ekingwin.bas.cloud.infra.utils.web.UserUtils;
import com.ekingwin.bas.cloud.org.OrganizationException;
import com.ekingwin.bas.cloud.org.dao.IOrganizationTreeDao;
import com.ekingwin.bas.cloud.org.dao.entity.OrganizationTree;
import com.ekingwin.bas.cloud.org.dto.OrganizationDto;
import com.ekingwin.bas.cloud.org.dto.OrganizationTreeDto;
import com.ekingwin.bas.cloud.org.service.IOrganizationService;
import com.ekingwin.bas.cloud.org.service.IOrganizationTreeService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Service;
import tk.mybatis.mapper.entity.Example;

import java.util.ArrayList;
import java.util.List;


@Service
@Primary
public class OrganizationTreeServiceImpl extends BaseService implements IOrganizationTreeService {

	@Autowired
	private IOrganizationTreeDao orgTreeDao;
	
	@Autowired
	@Qualifier(value="organizationServiceImpl")
	private IOrganizationService orgService;
	
	@Override
	public boolean save(OrganizationTreeDto organizationTreeDto) throws OrganizationException {
		try {
			if (organizationTreeDto.getPid().equals("0") || StringUtils.isEmpty(organizationTreeDto.getPid())) {
				organizationTreeDto.setPid("1");
				
			}
			save(organizationTreeDto,OrganizationTree.class,orgTreeDao);
		} catch (Exception e) {
			log.error(e.getMessage(), e);
			throw new OrganizationException(e);
		}
		return true;
	}

	@Override
	public boolean delete(String id) throws BasException {
		orgTreeDao.deleteByPrimaryKey(id);
		return true;
	}

	@Override
	public PageCriteria<OrganizationTreeDto> query(QueryDTO query)
			throws OrganizationException {
		try {
			Example example = buildQuery(query, OrganizationTree.class);
			return query(query, 
						() -> orgTreeDao.selectByExample(example), 
						OrganizationTreeDto.class);
		} catch (BasException e) {
			log.error(e.getMessage(), e);
			throw new OrganizationException(e);
		}
	}
	
	@Override
	public PageCriteria<OrganizationTreeDto> getOrgByUser(QueryDTO query)
			throws OrganizationException {
		try {
			String userid = UserUtils.getCurrentUser();
			Example example = buildQuery(query, OrganizationTree.class);
			return query(query, 
					() -> orgTreeDao.getOrgByUser(example, userid), 
					OrganizationTreeDto.class);
		} catch (BasException e) {
			log.error(e.getMessage(), e);
			throw new OrganizationException(e);
		}
	}

	@Override
	public OrganizationTreeDto get(String id) throws OrganizationException {
		try {
			OrganizationTreeDto organizationTreeDto = get(OrganizationTreeDto.class, id, orgTreeDao);
			return organizationTreeDto;
		} catch (Exception e) {
			log.error(e.getMessage(), e);
			throw new OrganizationException(e.getMessage(),e);
		}
	}

	@Override
	public BaseResult<List<OrganizationTreeDto>> getChildTreeById(String id)
			throws OrganizationException {
        List<OrganizationTree> list = orgTreeDao.getChildTreeById(id);
		
		List<OrganizationTreeDto> dtoList = new ArrayList<OrganizationTreeDto>();
		for(OrganizationTree orgTree : list){
			try {
				OrganizationTreeDto dto = new OrganizationTreeDto();
				super.commonBuild(dto, orgTree);
				dtoList.add(dto);
			} catch (Exception e) {
				log.error(e.getMessage(), e);
				throw new OrganizationException(e.getMessage(),e);
			}
		}
		return ResultUtils.build(dtoList);
	}
	@Override
	public BaseResult<List<OrganizationTreeDto>> getDirectChildTreeById(OrganizationDto organizationDto)
			throws OrganizationException {
		List<OrganizationTree> list =new ArrayList<>();
		String id = organizationDto.getId();
		String isPost = organizationDto.getIsPost();
		if(id.equals("1")){
			list =orgTreeDao.getDirectChildTreeByIds(id);
		}else{
			list =orgTreeDao.getDirectChildTreeById(id,isPost);
		}

		List<OrganizationTreeDto> dtoList = new ArrayList<OrganizationTreeDto>();
		for(OrganizationTree orgTree : list){
			try {
				OrganizationTreeDto dto = new OrganizationTreeDto();
				super.commonBuild(dto, orgTree);
				if(null!=orgTreeDao.hasChildTreeById(dto.getId())) {
					dto.setParent(true);
				}else {
					dto.setParent(false);
				}
				dtoList.add(dto);
			} catch (Exception e) {
				log.error(e.getMessage(), e);
				throw new OrganizationException(e.getMessage(),e);
			}
		}
		return ResultUtils.build(dtoList);
	}

	@Override
	public List<OrganizationTreeDto> getChildCompanyById(String id)
			throws OrganizationException {
		 List<OrganizationTree> list = orgTreeDao.getChildCompanyById(id);
			
			List<OrganizationTreeDto> dtoList = new ArrayList<OrganizationTreeDto>();
			for(OrganizationTree orgTree : list){
				try {
					OrganizationTreeDto dto = new OrganizationTreeDto();
					super.commonBuild(dto, orgTree);
					dtoList.add(dto);
				} catch (Exception e) {
					log.error(e.getMessage(), e);
					throw new OrganizationException(e.getMessage(),e);
				}
			}
			return dtoList;
	}

	@Override
	public List<OrganizationTreeDto> findFirstTree()
			throws OrganizationException {
		String userid = UserUtils.getCurrentUser();
		 List<OrganizationTree> list = orgTreeDao.findFirstTree(userid);
			
			List<OrganizationTreeDto> dtoList = new ArrayList<OrganizationTreeDto>();
			for(OrganizationTree orgTree : list){
				try {
					OrganizationTreeDto dto = new OrganizationTreeDto();
					super.commonBuild(dto, orgTree);
					dtoList.add(dto);
				} catch (Exception e) {
					log.error(e.getMessage(), e);
					throw new OrganizationException(e.getMessage(),e);
				}
			}
			return dtoList;
	}

	@Override
	public List<OrganizationTreeDto> getFirstTree()
			throws OrganizationException {
		String userid = UserUtils.getCurrentUser();
		 List<OrganizationTree> list = orgTreeDao.getFirstTree(userid);
			
			List<OrganizationTreeDto> dtoList = new ArrayList<OrganizationTreeDto>();
			for(OrganizationTree orgTree : list){
				try {
					OrganizationTreeDto dto = new OrganizationTreeDto();
					super.commonBuild(dto, orgTree);
					dtoList.add(dto);
				} catch (Exception e) {
					log.error(e.getMessage(), e);
					throw new OrganizationException(e.getMessage(),e);
				}
			}
			return dtoList;
	}

	@Override
	public OrganizationTreeDto getOrgTreeByidAndLogid(String id) throws OrganizationException {
		try {
			String[] split = id.split(",");
			if (split.length > 1) {
				String oid=split[0];
				String logid=split[1];
				OrganizationTreeDto organizationTreeDto = orgTreeDao.getOrgTreeByid(oid,logid);
				return organizationTreeDto;
			}
		} catch (Exception e) {
			e.printStackTrace();
			throw new OrganizationException();
		}
		return null;
	}

	@Override
	public PageCriteria<OrganizationTreeDto> getOrganizationTreeByUserId(QueryDTO query)
			throws OrganizationException {
		try {
			String userid = UserUtils.getCurrentUser();
			Example example = buildQuery(query, OrganizationTree.class);
			return query(query, 
					() -> orgTreeDao.getOrganizationTreeByUserId(example, userid), 
					OrganizationTreeDto.class);
		} catch (BasException e) {
			log.error(e.getMessage(), e);
			throw new OrganizationException(e);
		}
	}

	@Override
	public BaseResult<List<OrganizationTreeDto>> queryOrgTree(QueryDTO orgQuery) throws OrganizationException {
		List<OrganizationTreeDto> organizationTreeDtoList  = new ArrayList<OrganizationTreeDto>();
		List<OrganizationTreeDto> result  = new ArrayList<OrganizationTreeDto>();
		List<OrganizationTree> organizationTreelist;
		try {
			organizationTreelist = orgTreeDao.queryOrgTree();
		} catch (Exception e) {
			throw new OrganizationException(e);
		}
		
		OrganizationTree organizationTree =new OrganizationTree();
		for(int i = 0 ; i < organizationTreelist.size() ; i++ ){
			OrganizationTreeDto organizationTreeDto =new OrganizationTreeDto();
			organizationTree = organizationTreelist.get(i);
		try {
			super.commonBuild(organizationTreeDto, organizationTree);
		} catch (Exception e) {
			throw new OrganizationException(e);
		}
		organizationTreeDtoList.add(i,organizationTreeDto);
		}
		for(int i = 0 ; i < organizationTreeDtoList.size() ; i++ ){
			OrganizationTreeDto organizationTreeDto1 = new OrganizationTreeDto();
			organizationTreeDto1=organizationTreeDtoList.get(i);
			if("0".equals(organizationTreeDto1.getType())){
				List<OrganizationTreeDto> children  = new ArrayList<OrganizationTreeDto>(); 
				organizationTreeDto1.setChildList(children);
				getTreeChildren(organizationTreeDto1.getId(), organizationTreeDtoList,children);
				result.add(organizationTreeDto1);
				
			}
		}
		return ResultUtils.build(result);
	}
	
	private void getTreeChildren(String pid , List<OrganizationTreeDto> organizationTreeDtoList , List<OrganizationTreeDto> children  ){
		for(int i = 0 ; i < organizationTreeDtoList.size() ; i++ ){
			OrganizationTreeDto organizationTreeDto = organizationTreeDtoList.get(i) ; 
			if(pid.equals(organizationTreeDto.getPid())){
				List<OrganizationTreeDto> newchildren  = new ArrayList<OrganizationTreeDto>(); 
				organizationTreeDto.setChildList(newchildren);
				getTreeChildren(organizationTreeDto.getId(), organizationTreeDtoList,newchildren);
				children.add(organizationTreeDto);
			}
		}

	}

	@Override
	public void genTreecode() throws OrganizationException {
		orgTreeDao.genTreecode();
		
	}

	@Override
	public void insertTreeByOrg() throws OrganizationException {
		orgTreeDao.insertTreeByOrg();
		
	}

	@Override
	public BaseResult<List<OrganizationTreeDto>> getTenantOrganization() throws BasException {
		String currentUserId = UserUtils.getCurrentUser();
		
		List<OrganizationTree> list = orgTreeDao.getTenantOrganizationByUserId(currentUserId);
		
		List<OrganizationTreeDto> dtoList = new ArrayList<OrganizationTreeDto>();
		for(OrganizationTree orgTree : list){
			try {
				OrganizationTreeDto dto = new OrganizationTreeDto();
				super.commonBuild(dto, orgTree);
				if(null!=orgTreeDao.hasChildTreeById(dto.getId())) {
					dto.setParent(true);
				}else {
					dto.setParent(false);
				}
				dtoList.add(dto);
			} catch (Exception e) {
				log.error(e.getMessage(), e);
				throw new OrganizationException(e.getMessage(),e);
			}
		}
		return ResultUtils.build(dtoList);
	}
}
