package com.ekingwin.bas.cloud.org.web;



import com.ekingwin.bas.cloud.infra.dto.BaseResult;
import com.ekingwin.bas.cloud.infra.dto.QueryDTO;
import com.ekingwin.bas.cloud.infra.utils.db.PageCriteria;
import com.ekingwin.bas.cloud.org.OrganizationException;
import com.ekingwin.bas.cloud.org.dto.OrganizationDto;
import com.ekingwin.bas.cloud.org.dto.OrganizationTreeDto;
import com.ekingwin.bas.cloud.org.service.IOrganizationTreeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.*;

import java.util.List;


@RestController
@RequestMapping("/org/tree")
@Api("添加系统中的组织树的增删改查")
public class OrganizationTreeController{
	@Autowired
	@Qualifier(value = "organizationTreeServiceImpl")
	private IOrganizationTreeService orgTreeSer;

	@RequestMapping(value = "/query", method = RequestMethod.POST)
	@ApiOperation("根据过滤条件组织树信息")
	public PageCriteria<OrganizationTreeDto> queryUser(
			@RequestBody(required = false) QueryDTO query) throws Exception {
		return orgTreeSer.query(query);
	}
	
	@RequestMapping(value = "/queryOrgByUser", method = RequestMethod.POST)
	@ApiOperation("查询当前用户下的组织")
	public PageCriteria<OrganizationTreeDto> queryOrgByUser(
			@RequestBody(required = false) QueryDTO query) throws Exception {
		return orgTreeSer.getOrgByUser(query);
	}

	@RequestMapping(value = "/save", method = RequestMethod.POST)
	@ApiOperation("对组织树的增加与修改")
	public boolean saveUser(@RequestBody OrganizationTreeDto com) throws Exception {
		return orgTreeSer.save(com);
	}

	@RequestMapping(value = "/get/{id}", method = RequestMethod.GET)
	@ApiOperation("根据id获取组织树信息")
	public OrganizationTreeDto getUser(@PathVariable(value = "id") String id)
			throws Exception {
		return orgTreeSer.get(id);
	}

	@RequestMapping(value = "/delete/{id}", method = RequestMethod.DELETE)
	@ApiOperation("根据id删除组织树信息")
	public boolean deleteUser(@PathVariable(value = "id") String id)
			throws Exception {
		return orgTreeSer.delete(id);
	}
	
	@RequestMapping(value = "/getChild/{id}", method = RequestMethod.POST)
	@ApiOperation("根据id获取所有子组织树")
	public BaseResult<List<OrganizationTreeDto>> getChildtreeById(@PathVariable(value = "id") String id)
			throws Exception {
		return orgTreeSer.getChildTreeById(id);
	}
	
	@RequestMapping(value = "/getDirectChildById", method = RequestMethod.POST)
	@ApiOperation("根据id获取下代子组织树")
	public BaseResult<List<OrganizationTreeDto>> getDirectChildById(@RequestBody(required = false) OrganizationDto organizationDto)
			throws Exception {
		String id = organizationDto.getId();
		return orgTreeSer.getDirectChildTreeById(organizationDto);
	}
	
	@RequestMapping(value = "/getChildCompany/{id}", method = RequestMethod.GET)
	@ApiOperation("根据id获取下一级公司或部门")
	public List<OrganizationTreeDto> getChildCompanyById(@PathVariable(value = "id") String id)
			throws Exception {
		return orgTreeSer.getChildCompanyById(id);
	}
	
	@RequestMapping(value = "/findFirstTree", method = RequestMethod.POST)
	@ApiOperation("选择授权组织")
	public List<OrganizationTreeDto> findFirstTree()
			throws Exception {
		return orgTreeSer.findFirstTree();
	}
	
	@RequestMapping(value = "/getFirstTree", method = RequestMethod.POST)
	@ApiOperation("选择岗位")
	public List<OrganizationTreeDto> getFirstTree()
			throws Exception {
		return orgTreeSer.getFirstTree();
	}
	
	@RequestMapping(value = "/getOrgTreeByidAndLogid/{id}", method = RequestMethod.GET)
	@ApiOperation("根据id获取组织树信息")
	public OrganizationTreeDto getOrgTreeByidAndLogid(@PathVariable(value = "id")String id) throws OrganizationException{
		return orgTreeSer.getOrgTreeByidAndLogid(id);
	}
	/**
	 * 查询组织机构树
	 * @param query
	 * @return
	 * @throws Exception
	 */
	@RequestMapping(value = "/queryOrgTree", method = RequestMethod.POST)
	public BaseResult<List<OrganizationTreeDto>> queryOrgTree(@RequestBody(required = false) QueryDTO query) throws Exception {
		return orgTreeSer.queryOrgTree(query);
	}
	
	@RequestMapping(value = "/gettenantorganization", method = RequestMethod.POST)
	@ApiOperation("根据id获取下代子组织树")
	public BaseResult<List<OrganizationTreeDto>> getTenantOrganization() throws Exception {
		return orgTreeSer.getTenantOrganization();
	}
	
}
