package com.ekingwin.bas.cloud.user.dao;

import com.ekingwin.bas.cloud.org.dto.OrganizationDto;
import com.ekingwin.bas.cloud.user.UserException;
import com.ekingwin.bas.cloud.user.dao.entity.User;
import com.ekingwin.bas.cloud.user.dto.*;
import com.ekingwin.bas.mapper.BasMapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;
import tk.mybatis.mapper.entity.Example;

import java.util.List;
import java.util.Map;

@Repository
public interface UserDao extends BasMapper<User> {
	public List<User> getUsersByOrg(@Param("example")Example example , @Param("orgid")String orgid);
	public List<User> getUsersByNotOrg(@Param("example")Example example,@Param("orgid")String orgid,@Param("userid")String userid);
	public List<User> getUsersByNotBen(@Param("example")Example example,@Param("userid")String userid);
	public List<User> getParentUserById(@Param("example")Example example,@Param("userid")String userid);
	/**
	 * 查询所有用户
	 * @param example
	 * @return
	 */
	public List<User> initializationUserPush(@Param("example")Example example);
	
	public List<User> getAllUserByOrg(String orgid);
	
	public List<User> getUsersByUser(@Param("example")Example example,@Param("userid")String userid);
	

	/**
	 * 根据phone查询员工信息
	 * @param phone
	 * @return
	 */
	public User getUserByPhone(@Param("phone")String phone,@Param("email")String email);
	/**
	 * 根据账号修改密码
	 * @param userid
	 * @param password
	 */
	public void changePassword(@Param("userid")String userid, @Param("password")String password);
	/**
	 * 根据员工id查询系统编码
	 * @param empuid
	 * @return
	 */
	public List<String> getSyscodeByUserId(@Param("id")String id);
	/**
	 * 查询数据库中是否存在该条数据，根据系统编码，员工登录账号，状态
	 * @param syscode
	 * @param empid
	 * @param status
	 * @return
	 */
	public int getNumBySysCodes(@Param("syscode")String syscode, @Param("empid")String empid, @Param("status")String status);
	/**
	 * 添加推送数据
	 * @param syscode
	 * @param empid
	 * @param cnname
	 * @param sex
	 * @param phone
	 * @param officephone
	 * @param external
	 * @param status
	 * @param string
	 */
	public void insertSystemUser(@Param("syscode")String syscode, @Param("empid")String empid, @Param("cnname")String cnname,
			@Param("sex")String sex, @Param("phone")String phone, @Param("officephone")String officephone,@Param("email")String email, @Param("external")String external,
			@Param("status")String status, @Param("operate")String operate);
	/**
	 * 根据用户id查询用户是超级管理员
	 * @param userid
	 * @return
	 */
	public int judgeAdminByUserId(@Param("userid")String userid);
	/**
	 * 通过点击的组织ID和登录用户ID,获取该组织下的所有员工
	 * @param example
	 * @param logid
	 * @param orgid
	 * @return
	 */
	public List<UserDto> getUserByLogIdAndOrgid(@Param("example")Example example, @Param("logid")String logid, @Param("orgid")String orgid);
	/**
	 * 根据登录id和组织id查询组织（岗位）下的所有员工
	 * @param example
	 * @param orgid
	 * @param logid
	 * @return
	 */
	public List<UserPostDto> getUserByOrgidAndLogid(@Param("example")Example example, @Param("orgid")String orgid, @Param("logid")String logid);
	/**
	 * 根据工号查询用户
	 * @param empid
	 * @return
	 */
	public List<User> getUserByEmpid(@Param("empid")String empid);
	/**
	 * 校验手机号码和验证码
	 * @param phone
	 * @param code
	 * @return
	 */
	public CodeChange checkCodeByPhoneAndCode(@Param("phone")String phone, @Param("code")String code);
	
	public void deleteCodeById(@Param("id")String id);
	/**
	 * 管理员获取角色初始化--身份管理-组织
	 * @param example
	 * @param orgid
	 * @return
	 */
	public List<UserPostDto> getUserAllByOrgid(@Param("example")Example example, @Param("orgid")String orgid);
	/**
	 * 根据用户id获取用户对应的系统
	 * @param empuid
	 * @return
	 */
	public List<String> getSystemcodeByUserId(@Param("empuid")String empuid);
	
	public AccountDispose getAccountMappingByAccAndSyscode(@Param("account")String account, @Param("syscode")String syscode);
	public boolean deleteAccountByAccAndSyscode(@Param("account")String account, @Param("syscode")String syscode);
	public List<User> getUserByMobile(@Param("mobile")String mobile);
	public List<User> getAllUserByLogid(@Param("example")Example example);
	public List<User> getUserByLogid(@Param("example")Example example, @Param("logid")String logid);
	
	public List<String> getAndPostByUserid(@Param("empuid")String empuid);
	
	/**
	 * 验证手机号码是否唯一
	 * @param phone
	 * @return
	 */
	public int verificationPhoneOnly(@Param("phone")String phone);

	/**
	 * 验证邮箱是否唯一
	 * @param email
	 * @return
	 */
	public int verificationEmailOnly(@Param("email")String email);
	/**
	 * 根据岗位id获取岗位名称及上级部门名称和id
	 * @param defaultposid
	 * @return
	 */
	public DefaultPostDto getPostDefalutByDefaultposid(@Param("defaultposid")String defaultposid);
	
	public UserDto getUserInfo(@Param("userId")String userId);
	/**
	 * 获取全量岗位全路径
	 * @return
	 */
	public List<OrganizationDto> getPostInfo();
	
	/**
	 * 根据用户id获取有推送员工跟岗位权限的系统编码
	 * @param userid
	 * @return
	 */
	public List<String> getSystemcodeAndPostUserByUserId(@Param("userid")String userid);
	
	public void updateUserStatus(@Param("userid")String userid,@Param("status")String status);
	
	
	public void disableAccount(@Param("userid")String userid) throws UserException;
	
	public String getEmpuidByEmpid(String empid);
	public void enableAccount(@Param("userid")String userid) throws UserException;
	/**
	 * 更具手机，邮箱、账号获取用户信息
	 * @param object
	 * @return
	 * @throws UserException
	 */
	public List<User> getEmployeeByMobilephoneEmpuidEmail(@Param("object")String object) throws UserException;
	
	/**
	 * 状态删除用户
	 * @param id
	 */
	public void deleteById(String id); 
	
	/**
	 * 查询用户的状态
	 */
	
	public List<User> getStatus(@Param("id")String id);
	
	/**
	 * 手机，邮箱、账号获取用户信息(包括账号已禁用的)
	 */
	public List<Map<String, Object>> getEmployeesByMobilephoneEmpuidEmail(@Param("object")String object);
	/**
	 * 清除用户手机
	 */
	public void clearPhoneByEmpuid(@Param("empuid")String empuid);
	
	/**
	 * 清除用户邮箱
	 */
	public void clearEmailByEmpuid(@Param("empuid")String empuid);
    /**
	 * 查询租户下所有内部用户
	 * @param example
	 * @param empuid
	 * @return
	 */
	public List<UserDto> selectUserByEmpuid(@Param("example")Example example,@Param("empuid")String empuid);
    /**
     * 把删除的人员数据保存到数据库
     */
	public void insertUser(@Param("empuid")String empuid);
	/**
	 * 设置是否首次登陆
	 * @param firstlogin
	 * @param userid
	 */
	public void updateFirstlogin(@Param("firstlogin")String firstlogin,@Param("userid")String userid);
	/**
	 * 更新用户的上级领导
	 * @param empuid
	 * @param superiorname
	 * @param superior
	 */
	public void updateSuperior(@Param("empuid")String empuid,@Param("superiorname")String superiorname,@Param("superior")String superior);
	/*
	 * 查询主岗位
	 */
	public String getPName(@Param("empuid")String empuid);

	/**
	 * 根据手机号修改供应商密码
	 *
	 */
	int updatePwdByPhoneForSup(@Param("dataSource") String dataSource,@Param("way")String way,@Param("password")String password,@Param("account")String account);

	/**
	 * 根据手机号修改采购商密码
	 *
	 */
	int updatePwdByPhoneForPur(@Param("way")String way,@Param("password")String password,@Param("account")String account);


	/**
	 * 根据用户账户查询供应商平台的手机号和邮箱
	 */
	Map<String,String> getPhoneAndMailForSup(@Param("dataSource") String dataSource,@Param(value="account") String account);

	/**
	 * 根据用户账户查询采购平台的手机号和邮箱
	 * @param account
	 * @return
	 */
	Map<String,String> getPhoneAndMailForPur(@Param(value="account") String account);

	/**
	 * 根据登录账户查询供应商的密码
	 */
	Map<String,Object> getPasswordBySup(@Param("dataSource") String dataSource,@Param(value="account") String account);


	/**
	 * 同步用户到bpm引擎  natasha库里
	 * @param user
	 * @return
	 */
	public void saveUser(User user);
	/**
	 * 保存外部用户到sunac_bas employee表
	 */
	public void saveUserToEmployee(User user);
	/**
	 * 保存外部用户到bpm引擎
	 * @param user
	 * @return
	 */
	public void saveUserToBpm(User user);

	/**
	 * 根据登录账户查询采购商密码
	 */
	Map<String,Object> getPasswordByPur(@Param(value="account") String account);

	/**
	 * 根据账号修改供应商密码
	 */
	int updatePwdByAccountForSup(@Param("dataSource") String dataSource,@Param("password")String password,@Param("account")String account);
	/**
	 * 根据账号修改采购商密码
	 */
	int updatePwdByAccountForPur(@Param("password")String password,@Param("account")String account);


	/**
	 *获取内部用户分页
	 * @param innerUserPageDto
	 * @return
	 */
	List<InnerUserDto> selectPage(InnerUserPageDto innerUserPageDto);
}