package com.ekingwin.bas.cloud.user.web;

import com.ekingwin.bas.cloud.user.dao.entity.IpcOutUser;
import com.ekingwin.bas.cloud.user.dto.IpcOutUserDto;
import com.ekingwin.bas.cloud.user.dto.IpcOutUserPageDto;
import com.ekingwin.bas.cloud.user.service.IpcOutUserService;
import com.ekingwin.bas.cloud.util.Result;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.logging.Logger;

@RestController
@RequestMapping("/outuser")
@Api("外部用户相关增删改查的基本方法api")
public class IpcOutUserController {

    @Autowired
    private IpcOutUserService ipcOutUserService;

    @RequestMapping(value = "/saveOrUpdateUser", method = RequestMethod.POST)
    @ApiOperation("保存修改外部用户信息")
    public Result saveOrUpdateUser(@RequestBody IpcOutUserDto ipcOutUserDto) throws Exception {
        Long id=ipcOutUserService.saveOrUpdate(ipcOutUserDto);
        return Result.ok(id);

    }
    @RequestMapping(value = "/deleteUser", method = RequestMethod.POST)
    @ApiOperation("删除外部用户信息")
    public Result deleteUser(@RequestBody IpcOutUserDto ipcOutUserDto) throws Exception {
        ipcOutUserService.delete(ipcOutUserDto);
        return Result.ok();
    }

    @RequestMapping(value = "/batchDisable", method = RequestMethod.POST)
    @ApiOperation("批量禁用操作")
    public Result batchDisable(@RequestBody List<IpcOutUserDto> ipcOutUserDto) throws Exception {
        ipcOutUserService.batchDisable(ipcOutUserDto);
        return Result.ok();
    }
    @RequestMapping(value = "/batchEnabled", method = RequestMethod.POST)
    @ApiOperation("批量启用操作")
    public Result batchEnabled(@RequestBody List<IpcOutUserDto> ipcOutUserDto) throws Exception {
        ipcOutUserService.batchEnabled(ipcOutUserDto);
        return Result.ok();
    }
    @RequestMapping(value = "/operation", method = RequestMethod.POST)
    @ApiOperation("启用禁用操作,1表示启用，0表示禁用")
    public Result operation(@RequestBody IpcOutUserDto ipcOutUserDto) throws Exception {
        ipcOutUserService.operation(ipcOutUserDto);
        return Result.ok();
    }

    @RequestMapping(value = "/selectUser", method = RequestMethod.POST)
    @ApiOperation("查询外部用户信息")
    public Object selectUser(@RequestBody IpcOutUserDto ipcOutUserDto) throws Exception {
        Object o=ipcOutUserService.select(ipcOutUserDto);
        return Result.ok(o);
    }
    @RequestMapping(value = "/selectPage", method = RequestMethod.POST)
    @ApiOperation(value = "查询分页",response = IpcOutUserDto.class)
    public Result selectPage(@RequestBody IpcOutUserPageDto ipcOutUserPageDto) throws Exception {
        PageInfo<IpcOutUserDto> pageInfo  = ipcOutUserService.selectPage(ipcOutUserPageDto);
        return Result.ok(pageInfo);
    }

}
