package com.ekingwin.bas.cloud.user.web;


import java.util.Date;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.ekingwin.bas.cloud.enrollment.dto.EnrollmentDto;
import com.ekingwin.bas.cloud.infra.dto.BaseResult;
import com.ekingwin.bas.cloud.infra.dto.QueryDTO;
import com.ekingwin.bas.cloud.infra.utils.db.PageCriteria;
import com.ekingwin.bas.cloud.infra.utils.web.WebUtils;
import com.ekingwin.bas.cloud.user.dto.UserDto;
import com.ekingwin.bas.cloud.user.service.IUserMetaTenantService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping("/tenant/user")
@Api("用户usertenantController相关增删改查的基本方法api")
public class UserTenantController extends UserController{
	
	@Autowired
	@Qualifier(value = "userMetaTenantServiceImpl")
	private IUserMetaTenantService userService;
	
	@RequestMapping(value = "/deltete/{userId:.+}", method = RequestMethod.POST)
	public BaseResult<UserDto> deleteUser(@PathVariable(value = "userId")String userId) throws Exception {
		return userService.delete(userId);
	}
	
	@RequestMapping(value = "/saveUser", method = RequestMethod.POST)
	@ApiOperation("添加用户/修改用户")
	public BaseResult<UserDto> saveUser(@RequestBody UserDto user) throws Exception {		
		BaseResult<UserDto> baseResult = new BaseResult<UserDto>();
		baseResult.setTimestamp(String.valueOf(new Date().getTime()));
		baseResult.setPath(WebUtils.getRequest().getRequestURI());
		try {
			userService.save(user);
			baseResult.setStatus("200");
			baseResult.setData(user);
		} catch (Exception e) {
			baseResult.setStatus("500");
			baseResult.setMessage(e.getMessage());
		}
		return baseResult;
	}
	
	@RequestMapping(value = "/gettenantuser", method = RequestMethod.POST)
	@ApiOperation("根据租户id获取所有内部用户")
	public BaseResult<PageCriteria<UserDto>> getTenantUser(@RequestBody(required = false) QueryDTO query) throws Exception {
		return userService.getTenantUser(query);
	}
	
	@RequestMapping(value="/importemployee", method = RequestMethod.POST)
	@ApiOperation("excel导入用户")
	public BaseResult<UserDto> importemployee(@RequestParam(value = "file") MultipartFile file) throws Exception{
		BaseResult<UserDto> baseResult = new BaseResult<UserDto>();
		baseResult.setTimestamp(String.valueOf(new Date().getTime()));
		baseResult.setPath(WebUtils.getRequest().getRequestURI());
		try {
			userService.importemployee(file);
			baseResult.setStatus("200");
			baseResult.setData(null);
		} catch (Exception e) {
			baseResult.setStatus("500");
			baseResult.setMessage(e.getMessage());
		}
		return baseResult;
	}

	
}
